from troposphere import Template
from troposphere.codedeploy import (
    AutoRollbackConfiguration,
    DeploymentGroup,
    DeploymentStyle,
    Ec2TagFilters,
    Ec2TagSet,
    Ec2TagSetListObject,
    ElbInfoList,
    LoadBalancerInfo,
    OnPremisesInstanceTagFilters,
)

template = Template()
template.add_version('2010-09-09')


auto_rollback_configuration = AutoRollbackConfiguration(
    Enabled=True,
    Events=['DEPLOYMENT_FAILURE']
)

deployment_style = DeploymentStyle(
    DeploymentOption='WITH_TRAFFIC_CONTROL'
)

elb_info_list = ElbInfoList(
    Name='DemoLoadBalancer'
)

load_balancer_info = LoadBalancerInfo(
    ElbInfoList=[elb_info_list]
)

deployment_group = DeploymentGroup(
    "DemoDeploymentGroup",
    ApplicationName='DemoApplication',
    AutoRollbackConfiguration=auto_rollback_configuration,
    DeploymentStyle=deployment_style,
    LoadBalancerInfo=load_balancer_info,
    ServiceRoleArn='arn:aws:iam::0123456789:role/codedeploy-role'
)
template.add_resource(deployment_group)

# EC2 instances
deployment_group_ec2 = DeploymentGroup(
    "DemoDeploymentGroupEC2Instances",
    DeploymentGroupName='DemoApplicationEc2Instances',
    ApplicationName='DemoApplicationEc2Instances',
    AutoRollbackConfiguration=auto_rollback_configuration,
    DeploymentStyle=DeploymentStyle(
        DeploymentOption='WITHOUT_TRAFFIC_CONTROL'
    ),
    ServiceRoleArn='arn:aws:iam::0123456789:role/codedeploy-role',
    Ec2TagSet=Ec2TagSet(
        Ec2TagSetList=[
            Ec2TagSetListObject(
                Ec2TagGroup=[
                    Ec2TagFilters(
                        Key="CodeDeploy",
                        Type="KEY_AND_VALUE",
                        Value="activated"
                    ),
                    Ec2TagFilters(
                        Key="Environment",
                        Type="KEY_AND_VALUE",
                        Value="dev"
                    ),
                ]
            )
        ]
    )
)

template.add_resource(deployment_group_ec2)


# On premises
deployment_group_on_premises = DeploymentGroup(
    "DemoDeploymentGroupOnPremises",
    DeploymentGroupName='DemoApplicationOnPremises',
    ApplicationName='DemoApplicationOnPremises',
    AutoRollbackConfiguration=auto_rollback_configuration,
    DeploymentStyle=DeploymentStyle(
        DeploymentOption='WITHOUT_TRAFFIC_CONTROL'
    ),
    ServiceRoleArn='arn:aws:iam::0123456789:role/codedeploy-role',
    OnPremisesInstanceTagFilters=[OnPremisesInstanceTagFilters(
        Key='Service',
        Value='DemoApplicationOnPremises',
        Type='KEY_AND_VALUE'
    )]
)
template.add_resource(deployment_group_on_premises)

print(template.to_json())



from troposphere import GetAtt, Template, Tags
from troposphere.dlm import (LifecyclePolicy, PolicyDetails, Schedule,
                             RetainRule, CreateRule)
from troposphere.iam import Role
from awacs.aws import Allow, Statement, Principal, PolicyDocument
from awacs.sts import AssumeRole

t = Template()
t.add_version('2010-09-09')

dlm_role = t.add_resource(Role(
    "DlmRole",
    AssumeRolePolicyDocument=PolicyDocument(
        Statement=[
            Statement(
                Effect=Allow,
                Action=[AssumeRole],
                Principal=Principal("Service", ["ec2.amazonaws.com"])
            )
        ]
    )
))

lifecycle_policy = t.add_resource(LifecyclePolicy(
    "LifecyclePolicy",
    Description="Daily backup",
    State="ENABLED",
    ExecutionRoleArn=GetAtt(dlm_role, 'Arn'),
    PolicyDetails=PolicyDetails(
        ResourceTypes=[
            "VOLUME"
        ],
        TargetTags=Tags(
            Backup="True",
        ),
        Schedules=[
            Schedule(
                Name="Daily Snapshots",
                TagsToAdd=Tags(
                    type="DailySnapshot",
                ),
                CreateRule=CreateRule(
                    Interval=12,
                    IntervalUnit="HOURS",
                    Times=[
                        "13:00"
                    ]
                ),
                RetainRule=RetainRule(
                    Count=1
                ),
                CopyTags=True
            )
        ]
    )
))

print(t.to_json())



# Copyright (c) 2020, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from . import AWSObject, AWSProperty, Tags
from .validators import (resourcequery_type)


class TagFilter(AWSProperty):
    props = {
        'Key': (basestring, False),
        'Values': ([basestring], False),
    }


class Query(AWSProperty):
    props = {
        'ResourceTypeFilters': ([basestring], False),
        'StackIdentifier': (basestring, False),
        'TagFilters': ([TagFilter], False),
    }


class ResourceQuery(AWSProperty):
    props = {
        'Query': (Query, False),
        'Type': (resourcequery_type, False),
    }


class Group(AWSObject):
    resource_type = "AWS::ResourceGroups::Group"

    props = {
        'Description': (basestring, False),
        'Name': (basestring, True),
        'ResourceQuery': (ResourceQuery, False),
        'Tags': (Tags, False),
    }



from troposphere import Template
from troposphere import Tags
from troposphere.iotanalytics import (
    Channel,
    ChannelStorage,
    CustomerManagedS3,
    ServiceManagedS3,
    RetentionPeriod,
    Dataset,
    Action,
    DatasetContentDeliveryRule,
    DatasetContentDeliveryRuleDestination,
    S3DestinationConfiguration,
    Trigger,
    TriggeringDataset,
    VersioningConfiguration,
    Pipeline,
    Activity,
    ActivityChannel,
    ActivityDatastore,
    Datastore,
    DatastoreStorage,
)


t = Template()

channel = Channel(
    'TestChannel',
    ChannelName='testchannel',
    ChannelStorage=ChannelStorage(
        CustomerManagedS3=CustomerManagedS3(
            Bucket='customerbucket',
            KeyPrefix='bobdog',
            RoleArn='arn',
        )
    ),
    RetentionPeriod=RetentionPeriod(
        NumberOfDays=10,
    ),
    Tags=Tags(
        Manufacturer='AmazonWebServices'
    ),
)

pipeline = Pipeline(
    'TestPipeline',
    PipelineActivities=[
        Activity(
            Channel=ActivityChannel(
                ChannelName='ChannelName',
                Name='testchannel',
                Next='DatastoreActivity',
            ),
        ),
        Activity(
            Datastore=ActivityDatastore(
                Name='DatastoreActivity',
                DatastoreName='testdatastore',
            ),
        ),
    ],
    PipelineName='testpipeline',
    Tags=Tags(
        Manufacturer='AmazonWebServices'
    ),
)

datastore = Datastore(
    'TestDatastore',
    DatastoreName='testdatastore',
    DatastoreStorage=DatastoreStorage(
        ServiceManagedS3=ServiceManagedS3(),
    ),
    RetentionPeriod=RetentionPeriod(
        NumberOfDays=365,
    ),
    Tags=Tags(
        Manufacturer='AmazonWebServices'
    ),
)

dataset = Dataset(
    'TestDataset',
    Actions=[
        Action(
            ActionName='actionname',
        ),
    ],
    ContentDeliveryRules=[
        DatasetContentDeliveryRule(
            Destination=DatasetContentDeliveryRuleDestination(
                S3DestinationConfiguration=S3DestinationConfiguration(
                    Bucket='testbucket',
                    Key='testkey',
                    RoleArn='arn',
                ),
            ),
            EntryName='entryname',
        )
    ],
    DatasetName='testdataset',
    RetentionPeriod=RetentionPeriod(
        Unlimited=True,
    ),
    Tags=Tags(
        Manufacturer='AmazonWebServices'
    ),
    Triggers=[
        Trigger(
            TriggeringDataset=TriggeringDataset(
                DatasetName='testdataset'
            ),
        ),
    ],
    VersioningConfiguration=VersioningConfiguration(
        Unlimited=True,
    ),
)

t.add_resource(channel)
t.add_resource(pipeline)
t.add_resource(datastore)
t.add_resource(dataset)

print(t.to_json())



from troposphere import Ref, Template, Parameter
from troposphere.constants import STRING
import troposphere.ssm as ssm

t = Template()
t.set_description("2012-09-09")

rhel_patch_group_name = t.add_parameter(Parameter(
    "RHELPatchGroupName",
    Type=STRING,
    Description="The value of the RHEL patch group tag "
                "that will have the baseline applied to them."
        ))

windows_patch_group_name = t.add_parameter(Parameter(
    "WindowsPatchGroupName",
    Type=STRING,
    Description="The value of the Windows patch group tag"
                "that will have baseline applied to them."
))

linux_filter_group = ssm.PatchFilterGroup(
    "LinuxGroup",
    PatchFilters=[ssm.PatchFilter(
        "Linuxfilter",
        Key="CLASSIFICATION",
        Values=["Security"])]
)

windows_filter_group = ssm.PatchFilterGroup(
    "windowsGroup",
    PatchFilters=[ssm.PatchFilter(
        "WindowsFilter",
        Key="CLASSIFICATION",
        Values=["SecurityUpdates"])]
)

linux_rule_group = ssm.RuleGroup(
    "LinuxRuleGroup",
    PatchRules=[ssm.Rule(
                "LinuxBaseRule",
                ApproveAfterDays=90,
                ComplianceLevel="CRITICAL",
                PatchFilterGroup=linux_filter_group
                )]
        )

windows_rule_group = ssm.RuleGroup(
    "WindowsRuleGroup",
    PatchRules=[ssm.Rule(
                "WindowsBaseRule",
                ApproveAfterDays=90,
                ComplianceLevel="CRITICAL",
                PatchFilterGroup=windows_filter_group
                )]
)

t.add_resource(ssm.PatchBaseline(
            "RHELBASELINE",
            ApprovalRules=linux_rule_group,
            Description="Baseline containing all updates approved",
            Name=Ref(rhel_patch_group_name),
            OperatingSystem="REDHAT_ENTERPRISE_LINUX",
            PatchGroups=[Ref(rhel_patch_group_name)]

        ))

t.add_resource(ssm.PatchBaseline(
            "WINDOWSBASELINE",
            ApprovalRules=windows_rule_group,
            Description="Baseline containing all updates approved",
            Name=Ref(windows_patch_group_name),
            OperatingSystem="WINDOWS",
            PatchGroups=[Ref(windows_patch_group_name)]
        ))

print(t.to_json())



# Copyright (c) 2020, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from . import AWSObject, AWSProperty
from .validators import (integer, boolean, json_checker,
                         component_platforms, imagepipeline_status,
                         schedule_pipelineexecutionstartcondition,
                         ebsinstanceblockdevicespecification_volume_type)


class S3Logs(AWSProperty):
    props = {
        "S3BucketName": (basestring, False),
        "S3KeyPrefix": (basestring, False),
    }


class Logging(AWSProperty):
    props = {
        'S3Logs': (S3Logs, False),
    }


class InfrastructureConfiguration(AWSObject):
    resource_type = "AWS::ImageBuilder::InfrastructureConfiguration"

    props = {
        'Description': (basestring, False),
        'InstanceProfileName': (basestring, True),
        'InstanceTypes': ([basestring], False),
        'KeyPair': (basestring, False),
        'Logging': (Logging, False),
        'Name': (basestring, True),
        'SecurityGroupIds': ([basestring], False),
        'SnsTopicArn': (basestring, False),
        'SubnetId': (basestring, False),
        'Tags': (json_checker, False),
        'TerminateInstanceOnFailure': (boolean, False)
    }


class EbsInstanceBlockDeviceSpecification(AWSProperty):
    props = {
        'DeleteOnTermination': (boolean, False),
        'Encrypted': (boolean, False),
        'Iops': (integer, False),
        'KmsKeyId': (basestring, False),
        'SnapshotId': (basestring, False),
        'VolumeSize': (integer, False),
        'VolumeType': (ebsinstanceblockdevicespecification_volume_type, False),
    }


class InstanceBlockDeviceMapping(AWSProperty):
    props = {
        'DeviceName': (basestring, False),
        'Ebs': (EbsInstanceBlockDeviceSpecification, False),
        'NoDevice': (boolean, False),
        'VirtualName': (basestring, False),
    }


class ComponentConfiguration(AWSProperty):
    props = {
        'ComponentArn': (basestring, False),
    }


class ImageRecipe(AWSObject):
    resource_type = "AWS::ImageBuilder::ImageRecipe"

    props = {
        'BlockDeviceMappings': ([InstanceBlockDeviceMapping], False),
        'Components': ([ComponentConfiguration], True),
        'Description': (basestring, False),
        'Name': (basestring, True),
        'ParentImage': (basestring, True),
        'Tags': (json_checker, False),
        'Version': (basestring, True)
    }


class ImageTestsConfiguration(AWSProperty):
    props = {
        'ImageTestsEnabled': (boolean, False),
        'TimeoutMinutes': (integer, False),
    }


class Schedule(AWSProperty):
    props = {
        'PipelineExecutionStartCondition': (schedule_pipelineexecutionstartcondition, False),  # NOQA
        'ScheduleExpression': (basestring, False),
    }


class ImagePipeline(AWSObject):
    resource_type = "AWS::ImageBuilder::ImagePipeline"

    props = {
        'Description': (basestring, False),
        'DistributionConfigurationArn': (basestring, False),
        'ImageRecipeArn': (basestring, True),
        'ImageTestsConfiguration': (ImageTestsConfiguration, False),
        'InfrastructureConfigurationArn': (basestring, True),
        'Name': (basestring, True),
        'Schedule': (Schedule, False),
        'Status': (imagepipeline_status, False),
        'Tags': (json_checker, False),
    }


class Distribution(AWSProperty):
    props = {
        'AmiDistributionConfiguration': (json_checker, False),
        'LicenseConfigurationArns': ([basestring], False),
        'Region': (basestring, False),
    }


class DistributionConfiguration(AWSObject):
    resource_type = "AWS::ImageBuilder::DistributionConfiguration"

    props = {
        'Description': (basestring, False),
        'Distributions': ([Distribution], True),
        'Name': (basestring, True),
        'Tags': (json_checker, False),
    }


class Component(AWSObject):
    resource_type = "AWS::ImageBuilder::Component"

    props = {
        'ChangeDescription': (basestring, False),
        'Description': (basestring, False),
        'KmsKeyId': (basestring, False),
        'Name': (basestring, True),
        'Platform': (component_platforms, True),
        'Tags': (json_checker, False),
        'Uri': (basestring, False),
        'Version': (basestring, True),
    }



# Copyright (c) 2020, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from . import AWSObject, AWSProperty, Tags
from .validators import (integer, boolean, canary_runtime_version)


class VPCConfig(AWSProperty):
    props = {
        'SecurityGroupIds': ([basestring], True),
        'SubnetIds': ([basestring], True),
        'VpcId': (basestring, False),
    }


class Schedule(AWSProperty):
    props = {
        'DurationInSeconds': (basestring, True),
        'Expression': (basestring, True),
    }


class RunConfig(AWSProperty):
    props = {
        'TimeoutInSeconds': (integer, True),
    }


class Code(AWSProperty):
    props = {
        'Handler': (basestring, False),
        'S3Bucket': (basestring, False),
        'S3Key': (basestring, False),
        'S3ObjectVersion': (basestring, False),
        'Script': (basestring, False),
    }


class Canary(AWSObject):
    resource_type = "AWS::Synthetics::Canary"

    props = {
        'ArtifactS3Location': (basestring, True),
        'Code': (Code, True),
        'ExecutionRoleArn': (basestring, True),
        'FailureRetentionPeriod': (integer, False),
        'Name': (basestring, True),
        'RunConfig': (RunConfig, False),
        'RuntimeVersion': (canary_runtime_version, True),
        'Schedule': (Schedule, True),
        'StartCanaryAfterCreation': (boolean, True),
        'SuccessRetentionPeriod': (integer, False),
        'Tags': (Tags, False),
        'VPCConfig': (VPCConfig, False),
    }



from troposphere import Template, Join, Ref
from troposphere.secretsmanager import (Secret, GenerateSecretString,
                                        SecretTargetAttachment)
from troposphere.rds import DBInstance

t = Template()
t.add_version('2010-09-09')

DbSecret = t.add_resource(Secret(
    "DbSecret",
    Name="DbSecret",
    Description="This is the RDS instance master password",
    GenerateSecretString=GenerateSecretString(
        SecretStringTemplate="{\"username\":\"admin\"}",
        GenerateStringKey="password",
        PasswordLength=30,
    ),
))

Instance = t.add_resource(DBInstance(
    "Instance",
    AllocatedStorage="20",
    DBInstanceClass="db.t2.micro",
    Engine="mysql",
    DBInstanceIdentifier="TestInstance",
    MasterUsername=Join("", [
        "{{resolve:secretsmanager:",
        {"Ref": "DbSecret"},
        ":SecretString:username}}"
    ]),
    MasterUserPassword=Join("", [
        "{{resolve:secretsmanager:",
        {"Ref": "DbSecret"},
        ":SecretString:password}}"
    ])
))

t.add_resource(SecretTargetAttachment(
    "SecretRDSInstanceAttachment",
    TargetType="AWS::RDS::DBInstance",
    SecretId=Ref(DbSecret),
    TargetId=Ref(Instance),
))

print(t.to_json())



from troposphere import Template, Tags
from troposphere.secretsmanager import Secret, GenerateSecretString

t = Template()
t.add_version('2010-09-09')

MySecret = t.add_resource(Secret(
    "MySecret",
    Name="MySecret",
    Description="This is an autogenerated secret",
    GenerateSecretString=GenerateSecretString(
        SecretStringTemplate="{\"username\":\"test-user\"}",
        GenerateStringKey="password",
        PasswordLength=30,
    ),
    Tags=Tags(
        Appname="AppA"
    )
))

print(t.to_json())



# Copyright (c) 2020, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from . import AWSObject, AWSProperty, Tags


class TransitGatewayRegistration(AWSObject):
    resource_type = "AWS::NetworkManager::TransitGatewayRegistration"

    props = {
        'GlobalNetworkId': (basestring, True),
        'TransitGatewayArn': (basestring, True),
    }


class Location(AWSProperty):
    props = {
        'Address': (basestring, False),
        'Latitude': (basestring, False),
        'Longitude': (basestring, False),
    }


class Site(AWSObject):
    resource_type = "AWS::NetworkManager::Site"

    props = {
        'Description': (basestring, False),
        'GlobalNetworkId': (basestring, True),
        'Location': (Location, False),
        'Tags': (Tags, False),
    }


class LinkAssociation(AWSObject):
    resource_type = "AWS::NetworkManager::LinkAssociation"

    props = {
        'DeviceId': (basestring, True),
        'GlobalNetworkId': (basestring, True),
        'LinkId': (basestring, True),
    }


class Bandwidth(AWSProperty):
    props = {
        'DownloadSpeed': (basestring, False),
        'UploadSpeed': (basestring, False),
    }


class Link(AWSObject):
    resource_type = "AWS::NetworkManager::Link"

    props = {
        'Bandwidth': (Bandwidth, True),
        'Description': (basestring, False),
        'GlobalNetworkId': (basestring, True),
        'Provider': (basestring, False),
        'SiteId': (basestring, True),
        'Tags': (Tags, False),
        'Type': (basestring, False),
    }


class GlobalNetwork(AWSObject):
    resource_type = "AWS::NetworkManager::GlobalNetwork"

    props = {
        'Description': (basestring, False),
        'Tags': (Tags, False),
    }


class Device(AWSObject):
    resource_type = "AWS::NetworkManager::Device"

    props = {
        'Description': (basestring, False),
        'GlobalNetworkId': (basestring, True),
        'Location': (basestring, False),
        'Model': (basestring, False),
        'SerialNumber': (basestring, False),
        'SiteId': (basestring, False),
        'Tags': (Tags, False),
        'Type': (basestring, False),
        'Vendor': (basestring, False),
    }


class CustomerGatewayAssociation(AWSObject):
    resource_type = "AWS::NetworkManager::CustomerGatewayAssociation"

    props = {
        'CustomerGatewayArn': (basestring, True),
        'DeviceId': (basestring, True),
        'GlobalNetworkId': (basestring, True),
        'LinkId': (basestring, False),
    }



# Converted from DynamoDB_Table.template located at:
# http://aws.amazon.com/cloudformation/aws-cloudformation-templates/

from troposphere import Output, Parameter, Ref, Template
from troposphere.dynamodb import (KeySchema, AttributeDefinition,
                                  ProvisionedThroughput)
from troposphere.dynamodb import Table

t = Template()

t.set_description("AWS CloudFormation Sample Template: This template "
                  "demonstrates the creation of a DynamoDB table.")

hashkeyname = t.add_parameter(Parameter(
    "HashKeyElementName",
    Description="HashType PrimaryKey Name",
    Type="String",
    AllowedPattern="[a-zA-Z0-9]*",
    MinLength="1",
    MaxLength="2048",
    ConstraintDescription="must contain only alphanumberic characters"
))

hashkeytype = t.add_parameter(Parameter(
    "HashKeyElementType",
    Description="HashType PrimaryKey Type",
    Type="String",
    Default="S",
    AllowedPattern="[S|N]",
    MinLength="1",
    MaxLength="1",
    ConstraintDescription="must be either S or N"
))

readunits = t.add_parameter(Parameter(
    "ReadCapacityUnits",
    Description="Provisioned read throughput",
    Type="Number",
    Default="5",
    MinValue="5",
    MaxValue="10000",
    ConstraintDescription="should be between 5 and 10000"
))

writeunits = t.add_parameter(Parameter(
    "WriteCapacityUnits",
    Description="Provisioned write throughput",
    Type="Number",
    Default="10",
    MinValue="5",
    MaxValue="10000",
    ConstraintDescription="should be between 5 and 10000"
))

myDynamoDB = t.add_resource(Table(
    "myDynamoDBTable",
    AttributeDefinitions=[
        AttributeDefinition(
            AttributeName=Ref(hashkeyname),
            AttributeType=Ref(hashkeytype)
        ),
    ],
    KeySchema=[
        KeySchema(
            AttributeName=Ref(hashkeyname),
            KeyType="HASH"
        )
    ],
    ProvisionedThroughput=ProvisionedThroughput(
        ReadCapacityUnits=Ref(readunits),
        WriteCapacityUnits=Ref(writeunits)
    )
))

t.add_output(Output(
    "TableName",
    Value=Ref(myDynamoDB),
    Description="Table name of the newly create DynamoDB table",
))

print(t.to_json())



# Copyright (c) 2020, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from . import AWSObject


class ProfilingGroup(AWSObject):
    resource_type = "AWS::CodeGuruProfiler::ProfilingGroup"

    props = {
        'ProfilingGroupName': (basestring, True),
    }



# Copyright (c) 2012-2019, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***
# Resource specification version: 3.3.0


from . import AWSObject
from . import AWSProperty
from troposphere import Tags


VALID_HOMEDIRECTORY_TYPE = ('LOGICAL', 'PATH')


def validate_homedirectory_type(homedirectory_type):
    """Validate HomeDirectoryType for User"""

    if homedirectory_type not in VALID_HOMEDIRECTORY_TYPE:  # NOQA
        raise ValueError("User HomeDirectoryType must be one of: %s" %  # NOQA
                         ", ".join(VALID_HOMEDIRECTORY_TYPE))
    return homedirectory_type


class EndpointDetails(AWSProperty):
    props = {
        'AddressAllocationIds': ([basestring], False),
        'SubnetIds': ([basestring], False),
        'VpcEndpointId': (basestring, False),
        'VpcId': (basestring, False),
    }


class IdentityProviderDetails(AWSProperty):
    props = {
        'InvocationRole': (basestring, True),
        'Url': (basestring, True),
    }


class Server(AWSObject):
    resource_type = "AWS::Transfer::Server"

    props = {
        'Certificate': (basestring, False),
        'EndpointDetails': (EndpointDetails, False),
        'EndpointType': (basestring, False),
        'IdentityProviderDetails': (IdentityProviderDetails, False),
        'IdentityProviderType': (basestring, False),
        'LoggingRole': (basestring, False),
        'Protocols': ([basestring], False),
        'Tags': (Tags, False),
    }


class HomeDirectoryMapEntry(AWSProperty):
    props = {
        'Entry': (basestring, True),
        'Target': (basestring, True),
    }


class User(AWSObject):
    resource_type = "AWS::Transfer::User"

    props = {
        'HomeDirectory': (basestring, False),
        'HomeDirectoryMappings': ([HomeDirectoryMapEntry], False),
        'HomeDirectoryType': (validate_homedirectory_type, False),
        'Policy': (basestring, False),
        'Role': (basestring, True),
        'ServerId': (basestring, True),
        'SshPublicKeys': ([basestring], False),
        'Tags': (Tags, False),
        'UserName': (basestring, True),
    }



# Copyright (c) 2020, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
from . import AWSObject, AWSProperty, Tags
from .validators import boolean, integer, double, json_checker


class DataflowEdge(AWSProperty):
    props = {
        'Destination': (basestring, True),
        'Source': (basestring, True),
    }


class MissionProfile(AWSObject):
    resource_type = "AWS::GroundStation::MissionProfile"

    props = {
        'ContactPostPassDurationSeconds': (integer, False),
        'ContactPrePassDurationSeconds': (integer, False),
        'DataflowEdges': ([DataflowEdge], True),
        'MinimumViableContactDurationSeconds': (integer, True),
        'Name': (basestring, True),
        'Tags': (Tags, False),
        'TrackingConfigArn': (basestring, True),
    }


class SocketAddress(AWSProperty):
    props = {
        'Name': (basestring, False),
        'Port': (integer, False),
    }


class DataflowEndpoint(AWSProperty):
    props = {
        'Address': (SocketAddress, False),
        'Name': (basestring, False),
    }


class SecurityDetails(AWSProperty):
    props = {
        'RoleArn': (basestring, False),
        'SecurityGroupIds': ([basestring], False),
        'SubnetIds': ([basestring], False),
    }


class EndpointDetails(AWSProperty):
    props = {
        'DataflowEndpoint': (DataflowEndpoint, False),
        'SecurityDetails': (SecurityDetails, False),
    }


class DecodeConfig(AWSProperty):
    props = {
        'UnvalidatedJSON': (json_checker, True),
    }


class DemodulationConfig(AWSProperty):
    props = {
        'UnvalidatedJSON': (json_checker, True),
    }


class Bandwidth(AWSProperty):
    props = {
        'Units': (basestring, True),
        'Value': (double, True),
    }


class Frequency(AWSProperty):
    props = {
        'Units': (basestring, True),
        'Value': (double, True),
    }


class SpectrumConfig(AWSProperty):
    props = {
        'Bandwidth': (Bandwidth, True),
        'CenterFrequency': (Frequency, True),
        'Polarization': (basestring, False),
    }


class AntennaDownlinkConfig(AWSProperty):
    props = {
        'SpectrumConfig': (SpectrumConfig, True),
    }


class AntennaDownlinkDemodDecodeConfig(AWSProperty):
    props = {
        'DecodeConfig': (DecodeConfig, True),
        'DemodulationConfig': (DemodulationConfig, True),
        'SpectrumConfig': (SpectrumConfig, True),
    }


class SpectrumConfig(AWSProperty):
    props = {
        'Bandwidth': (Bandwidth, True),
        'CenterFrequency': (Frequency, True),
        'Polarization': (basestring, False),
    }


class DataflowEndpointGroup(AWSObject):
    resource_type = "AWS::GroundStation::DataflowEndpointGroup"

    props = {
        'EndpointDetailsList': ([EndpointDetails], True),
        'Tags': (Tags, False),
    }


class Eirp(AWSObject):
    props = {
        'Units': (basestring, True),
        'Value': (double, True),
    }


class AntennaUplinkConfig(AWSObject):
    props = {
        'SpectrumConfig': (SpectrumConfig, True),
        'TargetEirp': (Eirp, True),
    }


class DataflowEndpointConfig(AWSProperty):
    props = {
        'DataflowEndpointName': (basestring, True),
        'DataflowEndpointRegion': (basestring, False),
    }


class TrackingConfig(AWSProperty):
    props = {
        'AutoTrack': (basestring, True),
    }


class UplinkEchoConfig(AWSProperty):
    props = {
        'AntennaUplinkConfigArn': (basestring, True),
        'Enabled': (boolean, True),
    }


class ConfigData(AWSProperty):
    props = {
        'AntennaDownlinkConfig': (AntennaDownlinkConfig, False),
        'AntennaDownlinkDemodDecodeConfig': (AntennaDownlinkDemodDecodeConfig, False),  # NOQA
        'AntennaUplinkConfig': (AntennaUplinkConfig, False),
        'DataflowEndpointConfig': (DataflowEndpointConfig, False),
        'TrackingConfig': (TrackingConfig, False),
        'UplinkEchoConfig': (UplinkEchoConfig, False),
    }


class Config(AWSObject):
    resource_type = "AWS::GroundStation::Config"

    props = {
        'ConfigData': (ConfigData, True),
        'Name': (basestring, True),
        'Tags': (Tags, False),
    }



# Copyright (c) 2019, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
from . import AWSObject, AWSProperty, Tags
from .validators import boolean, integer, storage_type


VALID_LUSTRECONFIGURATION_DEPLOYMENTTYPE = ('PERSISTENT_1', 'SCRATCH_1',
                                            'SCRATCH_2')


VALID_LUSTRECONFIGURATION_PERUNITSTORAGETHROUGHPUT = (50, 100, 200)

def validate_lustreconfiguration_deploymenttype(lustreconfiguration_deploymenttype):  # NOQA
    """Validate DeploymentType for LustreConfiguration"""

    if lustreconfiguration_deploymenttype not in VALID_LUSTRECONFIGURATION_DEPLOYMENTTYPE:  # NOQA
        raise ValueError("LustreConfiguration DeploymentType must be one of: %s" %  # NOQA
                         ", ".join(VALID_LUSTRECONFIGURATION_DEPLOYMENTTYPE))
    return lustreconfiguration_deploymenttype


def validate_lustreconfiguration_perunitstoragethroughput(lustreconfiguration_perunitstoragethroughput):  # NOQA
    """Validate PerUnitStorageThroughput for LustreConfiguration"""

    if lustreconfiguration_perunitstoragethroughput not in VALID_LUSTRECONFIGURATION_PERUNITSTORAGETHROUGHPUT:  # NOQA
        raise ValueError("LustreConfiguration PerUnitStorageThroughput must be one of: %s" %  # NOQA
                         ", ".join(VALID_LUSTRECONFIGURATION_PERUNITSTORAGETHROUGHPUT))  # NOQA
    return lustreconfiguration_perunitstoragethroughput


class LustreConfiguration(AWSProperty):
    props = {
        'DeploymentType': (validate_lustreconfiguration_deploymenttype, False),
        'ExportPath': (basestring, False),
        'ImportedFileChunkSize': (integer, False),
        'ImportPath': (basestring, False),
        'PerUnitStorageThroughput': (validate_lustreconfiguration_perunitstoragethroughput, False),  # NOQA
        'WeeklyMaintenanceStartTime': (basestring, False),
    }


class SelfManagedActiveDirectoryConfiguration(AWSProperty):
    props = {
        'DnsIps': ([basestring], False),
        'DomainName': (basestring, False),
        'FileSystemAdministratorsGroup': (basestring, False),
        'OrganizationalUnitDistinguishedName': (basestring, False),
        'Password': (basestring, False),
        'UserName': (basestring, False),
    }


class WindowsConfiguration(AWSProperty):
    props = {
        'ActiveDirectoryId': (basestring, False),
        'AutomaticBackupRetentionDays': (integer, False),
        'CopyTagsToBackups': (boolean, False),
        'DailyAutomaticBackupStartTime': (basestring, False),
        'DeploymentType': (basestring, False),
        'PreferredSubnetId': (basestring, False),
        'SelfManagedActiveDirectoryConfiguration':
            (SelfManagedActiveDirectoryConfiguration, False),
        'ThroughputCapacity': (integer, False),
        'WeeklyMaintenanceStartTime': (basestring, False),
    }


class FileSystem(AWSObject):
    resource_type = 'AWS::FSx::FileSystem'

    props = {
        'BackupId': (basestring, False),
        'FileSystemType': (basestring, False),
        'KmsKeyId': (basestring, False),
        'LustreConfiguration': (LustreConfiguration, False),
        'SecurityGroupIds': ([basestring], False),
        'StorageCapacity': (integer, False),
        'StorageType': (storage_type, False),
        'SubnetIds': ([basestring], False),
        'Tags': (Tags, False),
        'WindowsConfiguration': (WindowsConfiguration, False),
    }



# Copyright (c) 2012-2020, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.


from . import AWSObject


VALID_SLACKCHANNELCONFIGURATION_LOGGINGLEVEL = ('ERROR', 'INFO', 'NODE')


def validate_logginglevel(slackchannelconfiguration_logginglevel):
    """Validate LoggingLevel for SlackChannelConfiguration"""

    if slackchannelconfiguration_logginglevel not in VALID_SLACKCHANNELCONFIGURATION_LOGGINGLEVEL:  # NOQA
        raise ValueError("SlackChannelConfiguration LoggingLevel must be one of: %s" %  # NOQA
                         ", ".join(VALID_SLACKCHANNELCONFIGURATION_LOGGINGLEVEL))  # NOQA
    return slackchannelconfiguration_logginglevel


class SlackChannelConfiguration(AWSObject):
    resource_type = "AWS::Chatbot::SlackChannelConfiguration"

    props = {
        'Arn': (basestring, False),
        'ConfigurationName': (basestring, True),
        'IamRoleArn': (basestring, True),
        'LoggingLevel': (validate_logginglevel, False),
        'SlackChannelId': (basestring, True),
        'SlackWorkspaceId': (basestring, True),
        'SnsTopicArns': ([basestring], False),
    }



# Copyright (c) 2012-2020, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.


from . import AWSObject


VALID_CONNECTION_PROVIDERTYPE = ('Bitbucket')


def validate_connection_providertype(connection_providertype):
    """Validate ProviderType for Connection"""

    if connection_providertype not in VALID_CONNECTION_PROVIDERTYPE:
        raise ValueError("Connection ProviderType must be one of: %s" %
                         ", ".join(VALID_CONNECTION_PROVIDERTYPE))
    return connection_providertype


class Connection(AWSObject):
    resource_type = "AWS::CodeStarConnections::Connection"

    props = {
        'ConnectionName': (basestring, True),
        'ProviderType': (validate_connection_providertype, True),
    }



# Copyright (c) 2012-2020, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from . import AWSObject, AWSProperty
from .validators import boolean, integer

VALID_WORKGROUP_STATE = ('ENABLED', 'DISABLED')
VALID_ENCRYPTIONCONFIGURATION_ENCRYPTIONOPTION = ('CSE_KMS', 'SSE_KMS',
                                                  'SSE_S3')


def validate_workgroup_state(workgroup_state):
    """Validate State for Workgroup"""

    if workgroup_state not in VALID_WORKGROUP_STATE:
        raise ValueError("Workgroup State must be one of: %s" %
                         ", ".join(VALID_WORKGROUP_STATE))
    return workgroup_state


def validate_encryptionconfiguration_encryptionoption(encryptionconfiguration_encryptionoption):  # NOQA
    """Validate EncryptionOption for EncryptionConfiguration"""

    if encryptionconfiguration_encryptionoption not in VALID_ENCRYPTIONCONFIGURATION_ENCRYPTIONOPTION:  # NOQA
        raise ValueError("EncryptionConfiguration EncryptionOption must be one of: %s" %  # NOQA
                         ", ".join(VALID_ENCRYPTIONCONFIGURATION_ENCRYPTIONOPTION))  # NOQA
    return encryptionconfiguration_encryptionoption


class NamedQuery(AWSObject):
    resource_type = "AWS::Athena::NamedQuery"

    props = {
        'Database': (basestring, True),
        'Description': (basestring, False),
        'Name': (basestring, False),
        'QueryString': (basestring, True),
    }


class EncryptionConfiguration(AWSProperty):
    props = {
        'EncryptionOption': (validate_encryptionconfiguration_encryptionoption,
                             False),
        'KmsKey': (basestring, False),
    }


class ResultConfiguration(AWSProperty):
    props = {
        'EncryptionConfiguration': (EncryptionConfiguration, False),
        'OutputLocation': (basestring, False),
    }


class WorkGroupConfiguration(AWSProperty):
    props = {
        'BytesScannedCutoffPerQuery': (integer, False),
        'EnforceWorkGroupConfiguration': (boolean, False),
        'PublishCloudWatchMetricsEnabled': (boolean, False),
        'RequesterPaysEnabled': (boolean, False),
        'ResultConfiguration': (ResultConfiguration, False),
    }


class ResultConfigurationUpdates(AWSProperty):
    props = {
        'EncryptionConfiguration': (EncryptionConfiguration, False),
        'OutputLocation': (basestring, False),
        'RemoveEncryptionConfiguration': (boolean, False),
        'RemoveOutputLocation': (boolean, False),
    }


class WorkGroupConfigurationUpdates(AWSProperty):
    props = {
        'BytesScannedCutoffPerQuery': (integer, False),
        'EnforceWorkGroupConfiguration': (boolean, False),
        'PublishCloudWatchMetricsEnabled': (boolean, False),
        'RemoveBytesScannedCutoffPerQuery': (boolean, False),
        'RequesterPaysEnabled': (boolean, False),
        'ResultConfigurationUpdates': (ResultConfigurationUpdates, False),
    }


class WorkGroup(AWSObject):
    resource_type = "AWS::Athena::WorkGroup"

    props = {
        'Description': (basestring, False),
        'Name': (basestring, True),
        'RecursiveDeleteOption': (boolean, False),
        'State': (validate_workgroup_state, False),
        'Tags': (dict, False),
        'WorkGroupConfiguration': (WorkGroupConfiguration, False),
        'WorkGroupConfigurationUpdates': (WorkGroupConfigurationUpdates,
                                          False),
    }



# Copyright (c) 2020, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from . import AWSObject


class CostCategory(AWSObject):
    resource_type = "AWS::CE::CostCategory"

    props = {
        'Name': (basestring, True),
        'Rules': (basestring, True),
        'RuleVersion': (basestring, True),
    }



# -*- coding: utf-8 -*-
"""
Setup
-----

Install troposphere in the current python environment.
"""
# ----------------------------------------------------------------------------
# Imports
# ----------------------------------------------------------------------------


# ---- Future
from __future__ import print_function
from __future__ import with_statement

# ---- System
import os
from setuptools import setup

# ----------------------------------------------------------------------------
# Helper Functions
# ----------------------------------------------------------------------------


def file_contents(file_name):
    """Given a file name to a valid file returns the file object."""
    curr_dir = os.path.abspath(os.path.dirname(__file__))
    with open(os.path.join(curr_dir, file_name)) as the_file:
        contents = the_file.read()
    return contents


def get_version():
    curr_dir = os.path.abspath(os.path.dirname(__file__))
    with open(curr_dir + "/troposphere/__init__.py", "r") as init_version:
        for line in init_version:
            if "__version__" in line:
                return str(line.split("=")[-1].strip(" ")[1:-2])

# ----------------------------------------------------------------------------
# Setup
# ----------------------------------------------------------------------------


setup(
    name='troposphere',
    version=get_version(),
    description="AWS CloudFormation creation library",
    long_description=file_contents("README.rst"),
    long_description_content_type='text/x-rst',

    author="Mark Peek",
    author_email="mark@peek.org",
    license="New BSD license",
    url="https://github.com/cloudtools/troposphere",

    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",

        "License :: OSI Approved :: BSD License",

        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: POSIX :: BSD",
        "Operating System :: POSIX :: Linux",

        "Programming Language :: Python",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 2.7",
    ],

    packages=[
        'troposphere',
        'troposphere.openstack',
        'troposphere.helpers'
    ],
    scripts=[
        'scripts/cfn',
        'scripts/cfn2py'
    ],

    python_requires=">=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*",
    install_requires=file_contents("requirements.txt"),
    test_suite="tests",
    tests_require=["awacs>=0.8"],
    extras_require={'policy': ['awacs>=0.8']},

    use_2to3=True,
)



# Copyright (c) 2020, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from . import AWSObject


class Graph(AWSObject):
    resource_type = "AWS::Detective::Graph"

    props = {
    }


class MemberInvitation(AWSObject):
    resource_type = "AWS::Detective::MemberInvitation"

    props = {
        'GraphArn': (basestring, True),
        'MemberEmailAddress': (basestring, True),
        'MemberId': (basestring, True),
        'Message': (basestring, False),
    }
